PACE package sparsisity analysis
================

-   [Chronic lymphocytic leukemia](#chronic-lymphocytic-leukemia)
    -   [What is a chronic leukemia](#what-is-a-chronic-leukemia)
    -   [What is a lymphocytic leukemia?](#what-is-a-lymphocytic-leukemia)
    -   [Are there different types of CLL?](#are-there-different-types-of-cll)
-   [Using L1, L2, Elastic net and each combination with DegreeCox](#using-l1-l2-elastic-net-and-each-combination-with-degreecox)
    -   [General Options](#general-options)
    -   [Install required packages](#install-required-packages)
    -   [Load library pace](#load-library-pace)
        -   [Setup parallel computing if necessary](#setup-parallel-computing-if-necessary)
    -   [Data](#data)
        -   [Expression levels](#expression-levels)
        -   [Select data with expression levels](#select-data-with-expression-levels)
    -   [Normalize matrix](#normalize-matrix)
-   [Regularization Setup](#regularization-setup)
    -   [Options](#options)
    -   [General function called in regularization](#general-function-called-in-regularization)
    -   [Setup xdata, ydata and functions](#setup-xdata-ydata-and-functions)
-   [Regularization](#regularization)
    -   [LASSO (l1 normalization)](#lasso-l1-normalization)
        -   [Lasso only](#lasso-only)
        -   [Degree-penalized Lasso](#degree-penalized-lasso)
    -   [Ridge (l2 normalization)](#ridge-l2-normalization)
        -   [Calculate Ridge only](#calculate-ridge-only)
        -   [Degree-penalized Ridge (**DegreeCox**)](#degree-penalized-ridge-degreecox)
    -   [Elastic net (l1 and l2 normalization)](#elastic-net-l1-and-l2-normalization)
        -   [Calculate Elastic Net only](#calculate-elastic-net-only)
        -   [Degree-penalized Elastic Net](#degree-penalized-elastic-net)
-   [Interesting genes](#interesting-genes)
    -   [L1 + L2 + Degree](#l1-l2-degree)

Chronic lymphocytic leukemia
============================

(information from [cancer.org](http://www.cancer.org/cancer/leukemia-chroniclymphocyticcll/detailedguide/leukemia-chronic-lymphocytic-what-is-cll))

Chronic lymphocytic leukemia (CLL) is a type of cancer that starts from cells that become certain white blood cells (called lymphocytes) in the bone marrow. The cancer (leukemia) cells start in the bone marrow but then go into the blood.

In CLL, the leukemia cells often build up slowly over time, and many people don't have any symptoms for at least a few years. In time, the cells can spread to other parts of the body, including the lymph nodes, liver, and spleen.

What is a chronic leukemia
--------------------------

Whether leukemia is acute or chronic depends on whether most of the abnormal cells are immature (and are more like stem cells) or mature (and are like normal white blood cells).

In chronic leukemia, the cells can mature partly but not completely. These cells may look fairly normal, but they are not. They generally do not fight infection as well as normal white blood cells do. The leukemia cells survive longer than normal cells, and build up, crowding out normal cells in the bone marrow. Chronic leukemias can take a long time before they cause problems, and most people can live for many years. But chronic leukemias are generally harder to cure than acute leukemias.

What is a lymphocytic leukemia?
-------------------------------

Whether leukemia is myeloid or lymphocytic depends on which bone marrow cells the cancer starts in.

Lymphocytic leukemias (also known as lymphoid or lymphoblastic leukemia) start in the cells that become lymphocytes. Lymphomas are also cancers that start in those cells. The main difference between lymphocytic leukemias and lymphomas is that in leukemia, the cancer cell is mainly in the bone marrow and blood, while in lymphoma it tends to be in lymph nodes and other tissues.

Are there different types of CLL?
---------------------------------

Doctors have found that there seem to be 2 different kinds of CLL:

1.  One kind of CLL grows very slowly and so it may take a long time before the patient needs treatment.
2.  The other kind of CLL grows faster and is a more serious disease.

The leukemia cells from these 2 types look alike, but lab tests can tell the difference between them. The tests look for proteins called ZAP-70 and CD38. If the CLL cells contain low amounts of these proteins, the leukemia tends to grow more slowly.

Using L1, L2, Elastic net and each combination with DegreeCox
=============================================================

General Options
---------------

``` r
nfolds       <- 5     # number of folds in cross-validation
nlambda      <- 100  # number of lambdas that should be calculated
is.parallel  <- TRUE  # use parallel computing (if available) in cross-validation?
#
# if all samples should be used, then training set = test set, otherwise
#  the two sets are complements.
training.set  <- .9
training.seed <- 65087 # reproducible results
#
training.set  <- 1
# selected from having at least 9 events in test set. (first - 45434 - has 11)
training.seed.list <- c(45434, 18628, 62002, 16801, 73033, 51529, 16239, 137920, 74779, 57774, 56389, 8164)
training.seed <- training.seed.list[4] # reproducible results
```

Install required packages
-------------------------

``` r
  # CRAN Packages
  required.pack <- c('KernSmooth','gplots', 'ggtern', 'maxstat', 'ggdendro', 
                     'forestplot', 'LSD', 'beeswarm', 'VennDiagram', 'doMC', 
                     'foreach', 'corrplot', 'survival', 'R.utils', 'Hmisc',
                     'glmnet', 'devtools', 'ggfortify')
  for (pack in required.pack) {
    if (!(pack %in% rownames(installed.packages()))) {
      install.packages(pack)
    }
  }
  # github
  devtools::install_github('averissimo/verissimo-rpackage')
```

    ## Skipping install of 'verissimo' from a github remote, the SHA1 (ccbe9fad) has not changed since last install.
    ##   Use `force = TRUE` to force installation

``` r
  # BioConductor packages
  source("https://bioconductor.org/biocLite.R")
```

    ## Bioconductor version 3.3 (BiocInstaller 1.22.3), ?biocLite for help

``` r
  required.pack.bioC <- c('vsn','genefilter')
  for (pack in required.pack.bioC) {
    if (!(pack %in% rownames(installed.packages()))) {
      biocLite(pack)
    }
  }
  # Pace packages from source
  if (!('pace' %in% rownames(installed.packages())))
    install.packages('./package', repos = NULL,type = 'source')
```

Load library pace
-----------------

This library was obtained from Wolfgang Huber in CSAMA 2016

``` r
suppressPackageStartupMessages({
  library(pace)
  library(Hmisc)
  library(futile.logger)
  library(digest)
  library(survival)
  library(glmnet)
  library(verissimo)
})
do.nothing <- flog.appender(appender.tee('logger.txt'))
```

### Setup parallel computing if necessary

``` r
suppressPackageStartupMessages({
  library(doMC) # parallel computing
  library(foreach)
})
# Parallel
registerDoMC(cores=10) 
```

Data
----

loading data from package and filter only by CLL

``` r
data(list=c("recipe", "conctab", "patmeta", "drugs", "mutCOM", "surv"))

lpdCLL <- lpdAll[ , lpdAll$Diagnosis=="CLL"   ]

rnaColumns <- lpdCLL@featureData@data$type == 'RNA'

expr <- lpdCLL@assayData$exprs[rnaColumns,]

flog.info('Columns for survival object:', colnames(survT), capture = TRUE)
```

    ## INFO [2016-09-15 00:04:56] Columns for survival object:
    ## 
    ##  [1] "T5"                  "T6"                  "treated"            
    ##  [4] "treatedAfter"        "died"                "IC50beforeTreatment"
    ##  [7] "IGHV"                "trisomy12"           "TP53"               
    ## [10] "del17p13"            "sampleStatus"

### Expression levels

Count the number of expression levels by sample to figure out which has missing values.

``` r
count.missing <- sapply(1:ncol(expr), function(e){sum(is.na(expr[,e]))})
flog.info('Number of samples with expression levels by sample: %d/%d', sum(count.missing == 0), ncol(lpdCLL))
```

    ## INFO [2016-09-15 00:04:56] Number of samples with expression levels by sample: 92/184

### Select data with expression levels

Get data that has all RNA-seq and calculate Pearson correlation on the genes. - When getting the correlation matrix, use the absolute values as edge weights

``` r
lpdCLL.rna <- lpdCLL[ , count.missing == 0]

if (training.set == 1) {
  lpdTest  <- lpdCLL.rna
  lpdTrain <- lpdCLL.rna
} else {
  sample.size <- floor(training.set * ncol(lpdCLL.rna))
  ## this commented code allows to find seeds that have a minimum of events
  ##  in test set
  #for(ix in 1:10000) {
  #  training.seed <- abs(floor(rnorm(1) * 100000))
  set.seed(training.seed)
  train.ix <- sample(seq_len(ncol(lpdCLL.rna)), size = sample.size)
  lpdTrain <- lpdCLL.rna[ ,  train.ix]
  lpdTest  <- lpdCLL.rna[ , -train.ix]
  #  if (sum(lpdTest@phenoData@data$died) == 9) {
  #    flog.info('Found it: %d', training.seed)
  #    # break
  #  }
  #}
      
  flog.info('Test data has %d samples that have died and %d that are censored.', 
            sum(lpdTest@phenoData@data$died),
            sum(!lpdTest@phenoData@data$died))
  # create variable with expression data
  # TODO: filter the assay data in lpdTrain to only RNA data
  expr <- lpdTrain@assayData$exprs[rnaColumns,]
}

# Must transpose the matrix, such as each column is a feature that will calculate the correlation
cor.pearson <- cor(t(expr), method = 'pearson')

# remove diagonal
diag(cor.pearson) <- 0

# set absolute values
cor.pearson.abs <- abs(cor.pearson)
```

Normalize matrix
----------------

``` r
# use the md5 digest to create a signature of the .abs to store .norm
cache.file <- file.path('cache', 
                        paste0('cor.pearson.abs.', 
                               digest(cor.pearson.abs, algo = 'md5'), 
                               '.RData'))

# if a cached file already exists with the same signature, then it should be used
#  instead of recalculating
if (file.exists(cache.file)) {
  flog.info('%s\n%s', 'Loading cache file instead of calculating all...',
            '  (note that cache file is referenced by md5sum of cor.pearson.abs matrix)')
  load(cache.file)
} else if (FALSE) {
  flog.info('Performing the normalization of cor.pearson.abs... (this could take a while)')
  sum.cols <- sqrt(colSums(cor.pearson.abs))
  sum.rows <- sqrt(rowSums(cor.pearson.abs))
  
  # divide the problem in 4 different partitions
  my.probs <- seq(0,1, 1 / (getDoParWorkers()))
  my.probs <- my.probs[2:length(my.probs)]
  quants <- c(0,round(quantile(1:nrow(cor.pearson.abs), probs = my.probs)))
  # for each partition calculate the normalization
  cor.pearson.norm <- foreach( ix = 2:length(quants), .combine = rbind ) %dopar% {
    # foreach was not very eficient done row by row, so this partion scheme
    #  must be done, probably a better parallization framework could have been
    #  used
    t(sapply((quants[ix-1] + 1):quants[ix], function(row.ix) {
      # actuall calculations done here
      sapply(1:ncol(cor.pearson.abs), function(col.ix) {
        cor.pearson.abs[row.ix,col.ix] / sum.cols[col.ix] / sum.rows[row.ix]
      })
    }))
    # seems like calculations are done pretty quick, rsession takes a while to
    #  join the results
  }
  save(file = cache.file, 'cor.pearson.norm')
}
# flog.info('cor.pearson.norm has size of %d rows and %d columns (which should be the same)',
#           nrow(cor.pearson.norm), ncol(cor.pearson.norm))
```

Calculate the degree of each node and normalize by column and row

``` r
# Simple sum of node edges
degree.abs <- 1 / colSums(cor.pearson.abs)
degree.abs <- degree.abs / max(degree.abs)
# Simple sum of node edges
# degree.norm <- 1 / colSums(cor.pearson.norm)
# degree.norm <- degree.norm / max(degree.norm)
# show summaries
flog.info('Summary on degree (absolute):',summary(degree.abs),capture = TRUE)
```

    ## INFO [2016-09-15 00:05:43] Summary on degree (absolute):
    ## 
    ##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max.    NA's 
    ##      NA      NA      NA     NaN      NA      NA   15366

``` r
# flog.info('Summary on degree (normalized):', summary(degree.norm), capture = TRUE)
# select which metric to use
degree <- degree.abs
degree[is.na(degree) || is.nan(degree) || is.infinite(degree)] <- 1
```

Regularization Setup
====================

Options
-------

Alpha parameter can be \[0,1\], where 0 is the same as Ridge and 1 Lasso. Anything in the middle is a weighted regularization between L1 and L2 norm.

General function called in regularization
-----------------------------------------

``` r
gen.foldid <- function(ydata) {
  # separate event and censored data
  ydata.event.ix <- which( ydata$status)
  ydata.censo.ix <- which(!ydata$status)
  # generate fold ids
  ydata.event.foldid <- sample(rep(seq(nfolds), length = length(ydata.event.ix)))
  ydata.censo.foldid <- sample(rep(seq(nfolds), length = length(ydata.censo.ix)))
  # consolidate
  foldid <- array(0, nrow(ydata)) 
  foldid[ydata.event.ix] <- ydata.event.foldid
  foldid[ydata.censo.ix] <- ydata.censo.foldid
  #
  return(foldid)
}

my.cv.glmnet <- function(xdata, ydata, penalty.factor) {
  return(cv.glmnet(xdata, Surv(ydata[,1], ydata[,2]), 
                   foldid = gen.foldid(ydata), parallel = is.parallel, 
                   family='cox', 
                   alpha = alpha, nlambda = nlambda, 
                   standardize = T, 
                   penalty.factor = penalty.factor))
}

print.results <- function(xdata, ydata, results, with.cox = F) {
  lambda.min.ix <- which(results$lambda == results$lambda.min)
  lambda.1se.ix <- which(results$lambda == results$lambda.1se)
  #
  lambda.chosen.ix <- sort(results$cvm, index.return =T)$ix[1]
  
  flog.info("best lambda: %f | non-zero: %d", results$lambda.min,
            sum(results$glmnet.fit$beta[,lambda.min.ix] != 0))
  flog.info(" 1se lambda: %f | non-zero: %d", results$lambda.1se,
            sum(results$glmnet.fit$beta[,lambda.1se.ix] != 0))
  flog.info(" chs lambda: %f | non-zero: %d", results$lambda[lambda.chosen.ix],
            sum(results$glmnet.fit$beta[,lambda.chosen.ix] != 0))
  # cox.model was not really required, just the coefficients
  if (with.cox) {
    cox.model <- coxph.fit(xdata, ydata, strata = NULL, init = results$glmnet.fit$beta[,lambda.min.ix], 
                           control = coxph.control(outer.max = 0, iter.max = 0), method = 'breslow',
                           rownames = NULL)
  } else {
  #
  # compatibility with coxph.fit model
  cox.model <- list(coefficients = results$glmnet.fit$beta[,lambda.min.ix])
  }
  return(cox.model)
}

my.draw.kaplan <- function(coeff, xdata, ydata, name) {
  my.list <- list()
  my.list[[name]] <- coeff
  draw.kaplan(my.list, xdata.test, ydata.test, 
              legend.outside = F, filename = name, expand.yzero = T)
}
```

Setup xdata, ydata and functions
--------------------------------

``` r
# xdata already setup above, but needs to be transposed
#     rows: observations
#  columns: features
xdata.test <- t(lpdTest@assayData$exprs[rnaColumns,])
ydata.test <- data.frame(time = lpdTest@phenoData@data$T6, 
                         status = lpdTest@phenoData@data$died, 
                         row.names = rownames(lpdTest@phenoData@data))
#
# xdata.test <- t(lpdCLL.rna@assayData$exprs[rnaColumns,])
# ydata.test <- data.frame(time = lpdCLL.rna@phenoData@data$T6,
#                          status = lpdCLL.rna@phenoData@data$died,
#                          row.names = rownames(lpdCLL.rna@phenoData@data))
#
xdata.train <- t(lpdTrain@assayData$exprs[rnaColumns,])
ydata.train <- data.frame(time = lpdTrain@phenoData@data$T6, 
                          status = lpdTrain@phenoData@data$died, 
                          row.names = rownames(lpdTrain@phenoData@data))
#
# adjust to months
ydata.test$time  <- ydata.test$time * 12
ydata.train$time <- ydata.train$time * 12
```

Regularization
==============

LASSO (l1 normalization)
------------------------

Using a sparse LASSO regularization with Cox proportional hazards model. When using the glmnet package, alpha should be 1.

``` r
alpha <- 1
```

### Lasso only

Run the model.

``` r
my.penalty   <- array(1,ncol(xdata.train))
results.l1   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l1 <- print.results(xdata.train, ydata.train, results.l1)
```

    ## INFO [2016-09-15 00:05:48] best lambda: 0.116523 | non-zero: 19
    ## INFO [2016-09-15 00:05:48]  1se lambda: 0.223480 | non-zero: 0
    ## INFO [2016-09-15 00:05:48]  chs lambda: 0.116523 | non-zero: 19

``` r
res          <- my.draw.kaplan(cox.model.l1$coefficients, 
                               xdata.test, ydata.test, "L1")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l1-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                 n events median 0.95LCL 0.95UCL
    ## Low risk - L1  46      0     NA      NA      NA
    ## High risk - L1 46     19   30.7    22.4      NA

### Degree-penalized Lasso

Penalizing the degree using the glmnet framework that includes a penalty.factor to control the shrinkage.

``` r
my.penalty         <- degree
results.l1.degree  <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l1.degre <- print.results(xdata.train, ydata.train, results.l1.degree)
```

    ## INFO [2016-09-15 00:05:54] best lambda: 0.092342 | non-zero: 26
    ## INFO [2016-09-15 00:05:54]  1se lambda: 0.177104 | non-zero: 8
    ## INFO [2016-09-15 00:05:54]  chs lambda: 0.092342 | non-zero: 26

``` r
res                <- my.draw.kaplan(cox.model.l1.degre$coefficients, 
                                     xdata.test, ydata.test, "L1 + Degree")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l1.degree-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                          n events median 0.95LCL 0.95UCL
    ## Low risk - L1 + Degree  46      0     NA      NA      NA
    ## High risk - L1 + Degree 46     19   30.7    22.4      NA

Ridge (l2 normalization)
------------------------

``` r
alpha <- 0
```

### Calculate Ridge only

``` r
my.penalty   <- array(1,ncol(xdata.train))
results.l2   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l2 <- print.results(xdata.train, ydata.train, results.l2)
```

    ## INFO [2016-09-15 00:06:02] best lambda: 60.755089 | non-zero: 15366
    ## INFO [2016-09-15 00:06:02]  1se lambda: 223.480290 | non-zero: 15366
    ## INFO [2016-09-15 00:06:02]  chs lambda: 60.755089 | non-zero: 15366

``` r
res          <- my.draw.kaplan(cox.model.l2$coefficients, 
                               xdata.test, ydata.test, "L2")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l2-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                 n events median 0.95LCL 0.95UCL
    ## Low risk - L2  46      0     NA      NA      NA
    ## High risk - L2 46     19   30.7    22.4      NA

### Degree-penalized Ridge (**DegreeCox**)

``` r
my.penalty          <- degree
results.l2.degree   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l2.degree <- print.results(xdata.train, ydata.train, results.l2.degree)
```

    ## INFO [2016-09-15 00:06:09] best lambda: 66.678635 | non-zero: 15366
    ## INFO [2016-09-15 00:06:09]  1se lambda: 203.626917 | non-zero: 15366
    ## INFO [2016-09-15 00:06:09]  chs lambda: 66.678635 | non-zero: 15366

``` r
res                 <- my.draw.kaplan(cox.model.l2.degree$coefficients, 
                                      xdata.test, ydata.test, "L2 + Degree")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l2_degree-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                          n events median 0.95LCL 0.95UCL
    ## Low risk - L2 + Degree  46      0     NA      NA      NA
    ## High risk - L2 + Degree 46     19   30.7    22.4      NA

Elastic net (l1 and l2 normalization)
-------------------------------------

``` r
alpha <- 0.5
```

### Calculate Elastic Net only

``` r
my.penalty      <- array(1,ncol(xdata.train))
results.l1.l2   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l1.l2 <- print.results(xdata.train, ydata.train, results.l1.l2)
```

    ## INFO [2016-09-15 00:06:14] best lambda: 0.193479 | non-zero: 44
    ## INFO [2016-09-15 00:06:14]  1se lambda: 0.338109 | non-zero: 18
    ## INFO [2016-09-15 00:06:14]  chs lambda: 0.193479 | non-zero: 44

``` r
res             <- my.draw.kaplan(cox.model.l1.l2$coefficients, 
                               xdata.test, ydata.test, "L1 + L2")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l1.l2-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                      n events median 0.95LCL 0.95UCL
    ## Low risk - L1 + L2  46      0     NA      NA      NA
    ## High risk - L1 + L2 46     19   30.7    22.4      NA

### Degree-penalized Elastic Net

``` r
my.penalty             <- degree
results.l1.l2.degree   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l1.l2.degree <- print.results(xdata.train, ydata.train, results.l1.l2.degree)
```

    ## INFO [2016-09-15 00:06:19] best lambda: 0.168278 | non-zero: 55
    ## INFO [2016-09-15 00:06:19]  1se lambda: 0.308073 | non-zero: 24
    ## INFO [2016-09-15 00:06:19]  chs lambda: 0.168278 | non-zero: 55

``` r
res                    <- my.draw.kaplan(cox.model.l1.l2.degree$coefficients, 
                                      xdata.test, ydata.test, "L1 + L2 + Degree")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l1.l2_degree-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                               n events median 0.95LCL 0.95UCL
    ## Low risk - L1 + L2 + Degree  46      0     NA      NA      NA
    ## High risk - L1 + L2 + Degree 46     19   30.7    22.4      NA

Interesting genes
=================

L1 + L2 + Degree
----------------

``` r
ix <- cox.model.l1.l2.degree$coefficients != 0
ix.names <- names(ix)[ix]
my.genes <- lpdTest@featureData@data[ix.names,]
if (!all(rownames(my.genes) == ix.names)) {
  for(i in 1:5) {flog.error('Problem ix!!') }
}
cbind(my.genes, l1.l2.degree = cox.model.l1.l2.degree$coefficients[ix])
```

    ##                                    name type   id subtype l1.l2.degree
    ## ENSG00000012124                    CD22  RNA <NA>    <NA> -0.002430285
    ## ENSG00000035720                   STAP1  RNA <NA>    <NA> -0.027883554
    ## ENSG00000048052                   HDAC9  RNA <NA>    <NA> -0.007364094
    ## ENSG00000067066                   SP100  RNA <NA>    <NA> -0.055331977
    ## ENSG00000069869                   NEDD4  RNA <NA>    <NA>  0.013571989
    ## ENSG00000077232                 DNAJC10  RNA <NA>    <NA> -0.024261573
    ## ENSG00000077585                 GPR137B  RNA <NA>    <NA> -0.129763198
    ## ENSG00000084693                   AGBL5  RNA <NA>    <NA>  0.072897358
    ## ENSG00000087448                  KLHL42  RNA <NA>    <NA>  0.202696039
    ## ENSG00000099204                  ABLIM1  RNA <NA>    <NA> -0.022569427
    ## ENSG00000100084                    HIRA  RNA <NA>    <NA> -0.034993678
    ## ENSG00000104154                 SLC30A4  RNA <NA>    <NA> -0.002963620
    ## ENSG00000106034                   CPED1  RNA <NA>    <NA> -0.057495326
    ## ENSG00000111424                     VDR  RNA <NA>    <NA>  0.008426575
    ## ENSG00000111445                    RFC5  RNA <NA>    <NA>  0.097017288
    ## ENSG00000111796                   KLRB1  RNA <NA>    <NA> -0.046285729
    ## ENSG00000112033                   PPARD  RNA <NA>    <NA> -0.007082833
    ## ENSG00000114739                  ACVR2B  RNA <NA>    <NA>  0.029418961
    ## ENSG00000123685                   BATF3  RNA <NA>    <NA>  0.073988709
    ## ENSG00000127561                  SYNGR3  RNA <NA>    <NA> -0.038481326
    ## ENSG00000132704                   FCRL2  RNA <NA>    <NA> -0.082193285
    ## ENSG00000136709                   WDR33  RNA <NA>    <NA> -0.510359198
    ## ENSG00000142945                   KIF2C  RNA <NA>    <NA>  0.048394654
    ## ENSG00000145390                   USP53  RNA <NA>    <NA> -0.051492822
    ## ENSG00000149639                   SOGA1  RNA <NA>    <NA>  0.005730905
    ## ENSG00000154316                     TDH  RNA <NA>    <NA> -0.013567765
    ## ENSG00000157240                    FZD1  RNA <NA>    <NA>  0.179531404
    ## ENSG00000162415                  ZSWIM5  RNA <NA>    <NA> -0.013392682
    ## ENSG00000163002                   NUP35  RNA <NA>    <NA> -0.023160390
    ## ENSG00000165113                   GKAP1  RNA <NA>    <NA> -0.055031858
    ## ENSG00000166147                    FBN1  RNA <NA>    <NA>  0.013189672
    ## ENSG00000166333                     ILK  RNA <NA>    <NA>  0.024219122
    ## ENSG00000170899                   GSTA4  RNA <NA>    <NA> -0.027466402
    ## ENSG00000175215                  CTDSP2  RNA <NA>    <NA>  0.051646805
    ## ENSG00000177410                   ZFAS1  RNA <NA>    <NA> -0.001925378
    ## ENSG00000181045                SLC26A11  RNA <NA>    <NA> -0.046521842
    ## ENSG00000181523                    SGSH  RNA <NA>    <NA> -0.081801837
    ## ENSG00000182162                   P2RY8  RNA <NA>    <NA> -0.058403512
    ## ENSG00000182389                  CACNB4  RNA <NA>    <NA>  0.248736024
    ## ENSG00000183323                 CCDC125  RNA <NA>    <NA> -0.135033545
    ## ENSG00000185760                   KCNQ5  RNA <NA>    <NA> -0.004504341
    ## ENSG00000186480                  INSIG1  RNA <NA>    <NA> -0.013191759
    ## ENSG00000187951 ARHGAP11B, LOC100288637  RNA <NA>    <NA>  0.260507681
    ## ENSG00000196648                          RNA <NA>    <NA> -0.009646976
    ## ENSG00000197582                          RNA <NA>    <NA> -0.007992890
    ## ENSG00000203778                 FAM229B  RNA <NA>    <NA> -0.095564828
    ## ENSG00000219928                          RNA <NA>    <NA> -0.210823974
    ## ENSG00000236268               LINC01361  RNA <NA>    <NA> -0.047019662
    ## ENSG00000242779                 ZNF702P  RNA <NA>    <NA>  0.033086789
    ## ENSG00000250966                          RNA <NA>    <NA> -0.095230398
    ## ENSG00000253653                          RNA <NA>    <NA> -0.074288806
    ## ENSG00000255103                          RNA <NA>    <NA>  0.023582733
    ## ENSG00000259976                          RNA <NA>    <NA> -0.004967181
    ## ENSG00000260121                          RNA <NA>    <NA>  0.123303554
    ## ENSG00000267002                          RNA <NA>    <NA>  0.129402828
